==> activity-center-api-0.7.1.wb-20170526.032649-1-sources.jar: cn/com/duiba/tuia/activity/center/api/remoteservice/RemotePluginService.java <==
/**
 * Project Name:activity-center-api<br>
 * File Name:RemotePluginService.java<br>
 * Package Name:cn.com.duiba.tuia.activity.center.api.remoteservice<br>
 * Date:2017年5月9日上午10:20:07<br>
 * Copyright (c) 2017, duiba.com.cn All Rights Reserved.<br>
 */

package cn.com.duiba.tuia.activity.center.api.remoteservice;

import java.util.List;

import cn.com.duiba.tuia.activity.center.api.common.PageDto;
import cn.com.duiba.tuia.activity.center.api.dto.ActivityPluginDto;
import cn.com.duiba.tuia.activity.center.api.dto.PluginOptionDto;
import cn.com.duiba.tuia.activity.center.api.dto.PluginSkinDto;
import cn.com.duiba.wolf.dubbo.DubboResult;

/**
 * ClassName: RemotePluginService <br/>
 * 活动插件工具Dubbo服务类 date: 2017年5月9日 上午10:20:07 <br/>
 * .
 *
 * @author youhaijun
 * @version
 * @since JDK 1.7
 */
public interface RemotePluginService {

    /**
     * 保存皮肤数据，根据ID是否存在区分是新增还是更新.
     *
     * @param dto the dto
     * @return the dubbo result< long>
     */
    DubboResult<Long> saveSkin(PluginSkinDto dto);

    /**
     * 根据皮肤ID查询皮肤详情. 调用方需要校验是否删除
     * 
     * @param id the id
     * @return the dubbo result< plugin skin dto>
     */
    DubboResult<PluginSkinDto> selectSkinById(Long id);

    /**
     * 分页查询有效皮肤列表，返回只包括id，名称.
     * 
     * @param offset the offset
     * @param max the max
     * @return the dubbo result< page dto< plugin skin dto>>
     */
    DubboResult<PageDto<PluginSkinDto>> selectSkinByPage(Integer offset, Integer max);

    /**
     * 根据插件id查询插件配置的奖项列表). <br/>
     *
     * @param pluginId the plugin id
     * @param includeStock 是否包含库存值(库存值需要调库存中心查询，不需要的话就不要查询)
     * @return the dubbo result< list< PluginOptionDto>>
     * @author youhaijun
     * @since JDK 1.7
     */
    DubboResult<List<PluginOptionDto>> selectOptionByPluginId(Long pluginId, Boolean includeStock);

    /**
     * 根据id查询奖项. <br/>
     *
     * @param optionId 奖项id
     * @return the dubbo result< activity option dto>
     * @author youhaijun
     * @since JDK 1.7
     */
    DubboResult<PluginOptionDto> selectOption(Long optionId);

    /**
     * saveActivityOption:(保存奖项). <br/>
     * 有id update <br/>
     * 无id insert <br/>
     *
     * @param options 批量保存奖项
     * @return 保存的数量
     * @author youhaijun
     * @since JDK 1.7
     */
    DubboResult<Integer> saveOption(List<PluginOptionDto> options);

    /**
     * 批量删除奖项. <br/>
     *
     * @param optionIds 奖项ids
     * @return 删除数量
     * @author youhaijun
     * @since JDK 1.7
     */
    DubboResult<Integer> deleteBatchOptions(List<Long> optionIds);

    /**
     * 保存活动插件工具，根据id区分新增和更新.
     *
     * @param dto the dto
     * @return the dubbo result< long>
     */
    DubboResult<Long> saveActivtiyPlugin(ActivityPluginDto dto);
    
    /**
     * 根据ID查询活动插件.
     *
     * @param id the id
     * @return the dubbo result< activity plugin dto>
     */
    DubboResult<ActivityPluginDto> selectActivityPluginById(Long id);
    
    /**
     * 分页查询活动插件列表，只返回id，状态和名称.
     *
     * @param offset the offset
     * @param max the max
     * @param id the id
     * @param title the title
     * @return the dubbo result< page dto< activity plugin dto>>
     */
    DubboResult<PageDto<ActivityPluginDto>> selectActivtiyPluginByPage(Integer offset, Integer max, Long id, String title);
    
    /**
     * 更新插件开启关闭状态.
     *
     * @param record the record
     * @return the dubbo result< integer>
     */
    DubboResult<Integer> updateOpenStatus(ActivityPluginDto record);
    
    /**
     * 更新插件开启关闭状态.
     *
     * @param record the record
     * @return the dubbo result< integer>
     */
    DubboResult<Integer> updateDirectApp(ActivityPluginDto record);
    
    /**
     * 根据ID删除活动插件.
     *
     * @param id the id
     * @return the dubbo result< boolean>
     */
    DubboResult<Integer> deletePluginById(Long id);
    
    /**
     * 删除插件皮肤.
     *
     * @param id the id
     * @return the dubbo result< integer>
     */
    DubboResult<Integer> deleteSkinById(Long id);
    
    /**
     * 查询可以投放的活动插件.
     * 筛选条件包括：是否开启，是否定向app，是否在触发时段中且没有自动关闭，当前页面是否在触发场景中，当前页面参与次数是否满足触发事件
     *
     * @return the dubbo result< activity plugin dto> 返回可以用来投放的一个插件工具，没有可用的时候返回空list,请校验
     */
    DubboResult<List<ActivityPluginDto>> selectAvailableActivityPlugin();
    
    
    /**
     * 根据皮肤ID查询此皮肤绑定的可用插件id，如有多个，返回最新的.
     *
     * @param skinId the skin id
     * @return the dubbo result< long>
     */
    DubboResult<Long> selectAvilPluginBySkinId(Long skinId);
}

==> activity-center-api-0.7.6.1.wb-20170802.082742-1-sources.jar: cn/com/duiba/tuia/activity/center/api/remoteservice/RemotePluginService.java <==
/**
 * Project Name:activity-center-api<br>
 * File Name:RemotePluginService.java<br>
 * Package Name:cn.com.duiba.tuia.activity.center.api.remoteservice<br>
 * Date:2017年5月9日上午10:20:07<br>
 * Copyright (c) 2017, duiba.com.cn All Rights Reserved.<br>
 */

package cn.com.duiba.tuia.activity.center.api.remoteservice;

import java.util.List;

import cn.com.duiba.tuia.activity.center.api.common.PageDto;
import cn.com.duiba.tuia.activity.center.api.dto.ActivityPluginDto;
import cn.com.duiba.tuia.activity.center.api.dto.PluginOptionDto;
import cn.com.duiba.tuia.activity.center.api.dto.PluginSkinDto;
import cn.com.duiba.wolf.dubbo.DubboResult;

/**
 * ClassName: RemotePluginService <br/>
 * 活动插件工具Dubbo服务类 date: 2017年5月9日 上午10:20:07 <br/>
 * .
 *
 * @author youhaijun
 * @version
 * @since JDK 1.7
 */
public interface RemotePluginService {

    /**
     * 保存皮肤数据，根据ID是否存在区分是新增还是更新.
     *
     * @param dto the dto
     * @return the dubbo result< long>
     */
    DubboResult<Long> saveSkin(PluginSkinDto dto);

    /**
     * 根据皮肤ID查询皮肤详情. 调用方需要校验是否删除
     * 
     * @param id the id
     * @return the dubbo result< plugin skin dto>
     */
    DubboResult<PluginSkinDto> selectSkinById(Long id);

    /**
     * 分页查询有效皮肤列表，返回只包括id，名称.
     * 
     * @param offset the offset
     * @param max the max
     * @return the dubbo result< page dto< plugin skin dto>>
     */
    DubboResult<PageDto<PluginSkinDto>> selectSkinByPage(Integer offset, Integer max);

    /**
     * 根据插件id查询插件配置的奖项列表). <br/>
     *
     * @param pluginId the plugin id
     * @param includeStock 是否包含库存值(库存值需要调库存中心查询，不需要的话就不要查询)
     * @return the dubbo result< list< PluginOptionDto>>
     * @author youhaijun
     * @since JDK 1.7
     */
    DubboResult<List<PluginOptionDto>> selectOptionByPluginId(Long pluginId, Boolean includeStock);

    /**
     * 根据id查询奖项. <br/>
     *
     * @param optionId 奖项id
     * @return the dubbo result< activity option dto>
     * @author youhaijun
     * @since JDK 1.7
     */
    DubboResult<PluginOptionDto> selectOption(Long optionId);

    /**
     * saveActivityOption:(保存奖项). <br/>
     * 有id update <br/>
     * 无id insert <br/>
     *
     * @param options 批量保存奖项
     * @return 保存的数量
     * @author youhaijun
     * @since JDK 1.7
     */
    DubboResult<Integer> saveOption(List<PluginOptionDto> options);

    /**
     * 批量删除奖项. <br/>
     *
     * @param optionIds 奖项ids
     * @return 删除数量
     * @author youhaijun
     * @since JDK 1.7
     */
    DubboResult<Integer> deleteBatchOptions(List<Long> optionIds);

    /**
     * 保存活动插件工具，根据id区分新增和更新.
     *
     * @param dto the dto
     * @return the dubbo result< long>
     */
    DubboResult<Long> saveActivtiyPlugin(ActivityPluginDto dto);
    
    /**
     * 根据ID查询活动插件.
     *
     * @param id the id
     * @return the dubbo result< activity plugin dto>
     */
    DubboResult<ActivityPluginDto> selectActivityPluginById(Long id);
    
    /**
     * 分页查询活动插件列表，只返回id，状态和名称.
     *
     * @param offset the offset
     * @param max the max
     * @param id the id
     * @param title the title
     * @return the dubbo result< page dto< activity plugin dto>>
     */
    DubboResult<PageDto<ActivityPluginDto>> selectActivtiyPluginByPage(Integer offset, Integer max, Long id, String title);


    /**
     * 分页查询活动插件列表，只返回id，状态和名称与插件类型.
     *
     * @param offset the offset
     * @param max the max
     * @param id the id
     * @param title the title
     * @return the dubbo result< page dto< activity plugin dto>>
     */
    DubboResult<PageDto<ActivityPluginDto>> selectActivtiyPluginByPage(Integer offset, Integer max, Long id, String title,Integer type);
    
    /**
     * 更新插件开启关闭状态.
     *
     * @param record the record
     * @return the dubbo result< integer>
     */
    DubboResult<Integer> updateOpenStatus(ActivityPluginDto record);
    
    /**
     * 更新插件开启关闭状态.
     *
     * @param record the record
     * @return the dubbo result< integer>
     */
    DubboResult<Integer> updateDirectApp(ActivityPluginDto record);
    
    /**
     * 根据ID删除活动插件.
     *
     * @param id the id
     * @return the dubbo result< boolean>
     */
    DubboResult<Integer> deletePluginById(Long id);
    
    /**
     * 删除插件皮肤.
     *
     * @param id the id
     * @return the dubbo result< integer>
     */
    DubboResult<Integer> deleteSkinById(Long id);
    
    /**
     * 查询可以投放的活动插件.
     * 筛选条件包括：是否开启，是否定向app，是否在触发时段中且没有自动关闭，当前页面是否在触发场景中，当前页面参与次数是否满足触发事件
     *
     * @return the dubbo result< activity plugin dto> 返回可以用来投放的一个插件工具，没有可用的时候返回空list,请校验
     */
    DubboResult<List<ActivityPluginDto>> selectAvailableActivityPlugin();

    /**
     * 查询可以投放的嵌入式插件 <br/>
     * 筛选条件：是否开启，是否定向app <br/>
     * 按优先级顺序返回。  <br/>
     * @param pageId 引导页id
     * @param blockName 区块名称
     * @return 按顺序返回
     */
    DubboResult<List<ActivityPluginDto>> selectAvailableEmbeddedPlugin(Long pageId,String blockName);
    
    
    /**
     * 根据皮肤ID查询此皮肤绑定的可用插件id，如有多个，返回最新的.
     *
     * @param skinId the skin id
     * @return the dubbo result< long>
     */
    DubboResult<Long> selectAvilPluginBySkinId(Long skinId);
}
